@@ -9,7 +9,7 @@ const testSsr = require('../src/testSsr.js');
 var arg = process.argv[2];
 
 var help = ' compile  :    Compile atom file; '
-           + '\n create   :    Create a swan project; '
+           + '\n create   :    Create an Atom project; '
            + '\n server   :    Run a server; '
            + '\n testSsr  :    Test if Server SSR commands is the same as App commands;';
 
@@ -25,12 +25,7 @@ if (!arg || arg === 'help') {
 	build();
 } else if (arg === 'testSsr') {
     var url = process.argv[3];
-    if (!url) {
-        console.log('you should input urlListUrl!');
-        process.exit();
-    } else {
-        testSsr(url);
-    }
+    testSsr(url);
 } else {
     console.log(help);
     process.exit();
